@@ -1,6 +1,6 @@
 package CatalystX::Resource;
 {
-    $CatalystX::Resource::VERSION = '0.001_005';
+    $CatalystX::Resource::VERSION = '0.001_006';
 }
 use Moose::Role;
 use CatalystX::InjectComponent;
@@ -9,13 +9,19 @@ use namespace::autoclean;
 # ABSTRACT: Provide CRUD functionality to your Controllers
 
 after 'setup_components' => sub {
-    my $class       = shift;
-    my $controllers = $class->config->{'CatalystX::Resource'}{'controllers'};
+    my $class = shift;
+
+    my $config      = $class->config->{'CatalystX::Resource'};
+    my $controllers = $config->{controllers};
+
     for my $controller (@$controllers) {
+        my $controller_name = 'Controller::' . $controller;
+        $class->config->{$controller_name}{error_path} = $config->{error_path}
+            if exists $config->{error_path};
         CatalystX::InjectComponent->inject(
             into      => $class,
             component => 'CatalystX::Resource::Controller::Resource',
-            as        => 'Controller::' . $controller,
+            as        => $controller_name,
         );
     }
 };
@@ -32,7 +38,7 @@ CatalystX::Resource - Provide CRUD functionality to your Controllers
 
 =head1 VERSION
 
-version 0.001_005
+version 0.001_006
 
 =head1 SYNOPSIS
 
@@ -47,6 +53,7 @@ version 0.001_005
             resource_key => 'artist',
             form_class => 'TestApp::Form::Resource::Artist',
             model => 'DB::Resource::Artist',
+            error_path => '/error',
             actions => {
                 base => {
                     PathPart => 'artists',
@@ -83,6 +90,26 @@ Using the Sortable trait your resources are sortable:
         traits => ['Sortable'],
     },
 
+=head1 CONFIG
+
+=head2 controllers
+
+array ref of controller names which will be injected into your app
+
+=head2 error_path
+
+where to detach to in case of an error (default: '/default')
+
+=head1 CAVEAT
+
+CatalystX::Resource detaches to $self->error_path if a resource cannot be found.
+Make sure you implement this action in your App. (default: '/default')
+
+=head1 SEE ALSO
+
+Check out L<Catalyst::Controller::DBIC::API> if you want to provide your data
+as a web service.
+
 =head1 AUTHOR
 
 David Schmidt <davewood@cpan.org>
